# SnowieCaster
This library was made for Snowie project to use Ariadne library.

It currently supports only in-memory backend, but it isn't release version

## Requirements
Python 3.6+
## Installation
* `pip install snowiecaster`

